@@ -75,6 +75,12 @@ class ApiSettings(ApiBase):
     def repository_details(self, name: str):
         return self.build_route(f"settings/repositories/{name}/details")
 
+    def repository_providers(self):
+        return self.build_route(f"settings/repository_providers")
+
+    def repository_provider(self, name: str):
+        return self.build_route(f"settings/repository_providers/{name}")
+
     def k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, sandbox_namespaces: str):
         return self.build_route("settings/cloudaccounts/computeservices/k8s/agent-deployment-yaml"
                                 "?cloudAccount={cloud_account_name}"
