@@ -198,25 +198,47 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
     # todo old function -> tomer delete this in phase 2
-    def add_azure_aks(self, name: str, cloud_account_name: str, kube_config: str):
+    def add_azure_aks(self,
+                      name: str,
+                      cloud_account_name: str,
+                      kube_config: str,
+                      ingress_controller_type: str = None,
+                      ingress_class: str = None,
+                      configure_dns: bool = False,
+                      generate_certificate: bool = False):
         """ Register AKS"""
         method_url = self._api_root.settings.add_compute_service_aks()
         request = {
             "kube_config": kube_config,
             "name": name,
-            "cloud_account_name": cloud_account_name
+            "cloud_account_name": cloud_account_name,
+            "ingress_controller_type": ingress_controller_type,
+            "ingress_class": ingress_class,
+            "configure_dns": configure_dns,
+            "generate_certificate": generate_certificate
         }
 
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
     # todo old function -> tomer delete this in phase 2
-    def add_aws_k8s_unmanaged(self, name: str, cloud_account_name: str, kube_config: str):
+    def add_aws_k8s_unmanaged(self,
+                              name: str,
+                              cloud_account_name: str,
+                              kube_config: str,
+                              ingress_controller_type: str = None,
+                              ingress_class: str = None,
+                              configure_dns: bool = False,
+                              generate_certificate: bool = False):
         method_url = self._api_root.settings.add_compute_service_aws_k8s_unmanaged()
         request = {
             "kube_config": kube_config,
             "name": name,
-            "cloud_account_name": cloud_account_name
+            "cloud_account_name": cloud_account_name,
+            "ingress_controller_type": ingress_controller_type,
+            "ingress_class": ingress_class,
+            "configure_dns": configure_dns,
+            "generate_certificate": generate_certificate
         }
 
         resp = self.session.post(url=method_url, json=request)
