@@ -888,9 +888,10 @@ class InvitedUserDetailsResponse:
 
 
 class RepositoryResponse:
-    def __init__(self, repository_url: str, errors: List[Error]):
+    def __init__(self, repository_url: str, errors: List[Error], branch: str):
         self.errors = errors
         self.repository_url = repository_url
+        self.branch = branch
 
 
 class RepositoryProviderResponse:
